@@ -1,7 +1,7 @@
 /*
  * libopenraw - cameraids.h
  *
- * Copyright (C) 2012-2020 Hubert Figuière
+ * Copyright (C) 2012-2022 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -18,7 +18,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 /**
- * @brief the libopenraw list of camera id.
+ * @file The libopenraw list of camera ID.
  * @author Hubert Figuière <hub@figuiere.net>
  */
 
@@ -27,13 +27,21 @@
 
 #include <stdint.h>
 
+/** @defgroup camera_id Camera IDs
+ * @ingroup public_api
+ *
+ * @brief The vendor and camera IDs.
+ *
+ * @{
+ */
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-/** The vendor ID: the high order 16-bits of the %or_rawfile_typeid
+/** @brief The vendor ID: the high order 16-bits of the or_rawfile_typeid
  */
-enum {
+enum _OR_TYPE_ID_VENDOR {
     OR_TYPEID_VENDOR_NONE = 0,
     OR_TYPEID_VENDOR_CANON = 1,
     OR_TYPEID_VENDOR_NIKON = 2,
@@ -47,8 +55,7 @@ enum {
     OR_TYPEID_VENDOR_RICOH = 10,
     OR_TYPEID_VENDOR_PANASONIC = 11,
     OR_TYPEID_VENDOR_MAMIYA = 12,
-    /* not really a camera vendor. For the converter. */
-    OR_TYPEID_VENDOR_ADOBE = 13,
+    OR_TYPEID_VENDOR_ADOBE = 13, /**< Generic DNG files. */
     OR_TYPEID_VENDOR_FUJIFILM = 14,
     OR_TYPEID_VENDOR_BLACKMAGIC = 15,
     OR_TYPEID_VENDOR_XIAOYI = 16,
@@ -56,20 +63,23 @@ enum {
     OR_TYPEID_VENDOR_SIGMA = 18,
     OR_TYPEID_VENDOR_GOPRO = 19,
     OR_TYPEID_VENDOR_HASSELBLAD = 20,
+    OR_TYPEID_VENDOR_ZEISS = 21,
+    OR_TYPEID_VENDOR_DJI = 22,
 
     _OR_TYPEID_VENDOR_LAST
 };
 
 enum { OR_TYPEID_UNKNOWN = 0 };
 
-enum {
+/** @brief Adobe type ID */
+enum _OR_TYPEID_VENDOR_ADOBE {
     OR_TYPEID_ADOBE_UNKNOWN = 0,
-    OR_TYPEID_ADOBE_DNG_GENERIC = 1,
+    OR_TYPEID_ADOBE_DNG_GENERIC = 1, /**< Generic DNG file. */
     _OR_TYPEID_ADOBE_LAST
 };
 
-/** Canon type IDs */
-enum {
+/** @brief Canon type IDs */
+enum _OR_TYPEID_VENDOR_CANON {
     OR_TYPEID_CANON_UNKNOWN = 0,
     OR_TYPEID_CANON_20D = 1,
     OR_TYPEID_CANON_30D = 2,
@@ -217,11 +227,27 @@ enum {
     OR_TYPEID_CANON_1DXMKIII = 100,
     OR_TYPEID_CANON_EOS_R5 = 101,
     OR_TYPEID_CANON_EOS_R6 = 102,
+    OR_TYPEID_CANON_S30 = 103,
+    OR_TYPEID_CANON_S40 = 104,
+    OR_TYPEID_CANON_S45 = 105,
+    OR_TYPEID_CANON_S50 = 106,
+    OR_TYPEID_CANON_S60 = 107,
+    OR_TYPEID_CANON_S70 = 108,
+    OR_TYPEID_CANON_S100V = 109,
+    OR_TYPEID_CANON_PRO70 = 110,
+    OR_TYPEID_CANON_PRO90 = 111,
+    OR_TYPEID_CANON_850D = 112,
+    OR_TYPEID_CANON_REBEL_T8I = OR_TYPEID_CANON_850D,
+    OR_TYPEID_CANON_KISS_X10I = OR_TYPEID_CANON_850D,
+    OR_TYPEID_CANON_EOS_M2 = 113,
+    OR_TYPEID_CANON_EOS_M50MKII = 114,
+    OR_TYPEID_CANON_KISS_M2 = OR_TYPEID_CANON_EOS_M50MKII,
+    OR_TYPEID_CANON_EOS_R3 = 115,
     _OR_TYPEID_CANON_LAST
 };
 
-/** Nikon type IDs */
-enum {
+/** @brief Nikon type IDs */
+enum _OR_TYPEID_VENDOR_NIKON {
     OR_TYPEID_NIKON_UNKNOWN = 0,
     OR_TYPEID_NIKON_E5700,
     OR_TYPEID_NIKON_D1,
@@ -302,11 +328,16 @@ enum {
     OR_TYPEID_NIKON_Z50,
     OR_TYPEID_NIKON_COOLPIX_P950,
     OR_TYPEID_NIKON_D6,
+    OR_TYPEID_NIKON_Z5,
+    OR_TYPEID_NIKON_Z6_2,
+    OR_TYPEID_NIKON_Z7_2,
+    OR_TYPEID_NIKON_ZFC,
+    OR_TYPEID_NIKON_Z9,
     _OR_TYPEID_NIKON_LAST
 };
 
-/** Leica type IDs */
-enum {
+/** @brief Leica type IDs */
+enum _OR_TYPEID_VENDOR_LEICA {
     OR_TYPEID_LEICA_UNKNOWN = 0,
     /* DNG */
     OR_TYPEID_LEICA_DMR = 1,
@@ -350,11 +381,18 @@ enum {
     OR_TYPEID_LEICA_SL2 = 31,
     OR_TYPEID_LEICA_M10_MONOCHROM = 32,
     OR_TYPEID_LEICA_M10R = 33,
+    OR_TYPEID_LEICA_M_MONOCHROM_TYP246 = 34,
+    /* RWL */
+    OR_TYPEID_LEICA_DLUX_4 = 35,
+    /* DNG */
+    OR_TYPEID_LEICA_SL2S = 36,
+    OR_TYPEID_LEICA_Q2_MONOCHROM = 37,
+    OR_TYPEID_LEICA_M11 = 38,
     _OR_TYPEID_LEICA_LAST
 };
 
-/** Pentax type IDs */
-enum {
+/** @brief Pentax type IDs */
+enum _OR_TYPEID_VENDOR_PENTAX {
     OR_TYPEID_PENTAX_UNKNOWN = 0,
     OR_TYPEID_PENTAX_K10D_PEF,
     OR_TYPEID_PENTAX_K10D_DNG,
@@ -402,19 +440,28 @@ enum {
     OR_TYPEID_PENTAX_KP_DNG,
     OR_TYPEID_PENTAX_K1_MKII_PEF,
     OR_TYPEID_PENTAX_K1_MKII_DNG,
+    OR_TYPEID_PENTAX_K7_DNG,
+    OR_TYPEID_PENTAX_IST_DL2_PEF,
+    OR_TYPEID_PENTAX_K5_II_PEF,
+    OR_TYPEID_PENTAX_K5_II_DNG,
+    OR_TYPEID_PENTAX_K3_PEF,
+    OR_TYPEID_PENTAX_K3_II_PEF,
+    OR_TYPEID_PENTAX_K110D_PEF,
+    OR_TYPEID_PENTAX_K3_MKIII_PEF = 54,
+    OR_TYPEID_PENTAX_K3_MKIII_DNG,
     _OR_TYPEID_PENTAX_LAST
 };
 
-/** Epson type IDs */
-enum {
+/** @brief Epson type IDs */
+enum _OR_TYPEID_VENDOR_EPSON {
     OR_TYPEID_EPSON_UNKNOWN = 0,
     OR_TYPEID_EPSON_RD1 = 1,
     OR_TYPEID_EPSON_RD1S = 2,
     _OR_TYPEID_EPSON_LAST
 };
 
-/** Minolta type IDs */
-enum {
+/** @brief Minolta type IDs */
+enum _OR_TYPEID_VENDOR_MINOLTA {
     OR_TYPEID_MINOLTA_UNKNOWN = 0,
     OR_TYPEID_MINOLTA_A1,
     OR_TYPEID_MINOLTA_A2,
@@ -428,7 +475,8 @@ enum {
     _OR_TYPEID_MINOLTA_LAST
 };
 
-enum {
+/** @brief Olympus (and its successor OM Digital Solutions type IDs */
+enum _OR_TYPEID_VENDOR_OLYMPUS {
     OR_TYPEID_OLYMPUS_UNKNOWN = 0,
     OR_TYPEID_OLYMPUS_E1,
     OR_TYPEID_OLYMPUS_E10,
@@ -440,9 +488,9 @@ enum {
     OR_TYPEID_OLYMPUS_E500,
     OR_TYPEID_OLYMPUS_E510,
     OR_TYPEID_OLYMPUS_SP350,
-    OR_TYPEID_OLYMPUS_SP510,
-    OR_TYPEID_OLYMPUS_SP550,
-    OR_TYPEID_OLYMPUS_SP500,
+    OR_TYPEID_OLYMPUS_SP510UZ,
+    OR_TYPEID_OLYMPUS_SP550UZ,
+    OR_TYPEID_OLYMPUS_SP500UZ,
     OR_TYPEID_OLYMPUS_EP1,
     OR_TYPEID_OLYMPUS_E620,
     OR_TYPEID_OLYMPUS_EPL1,
@@ -477,22 +525,29 @@ enum {
     OR_TYPEID_OLYMPUS_EM1X,
     OR_TYPEID_OLYMPUS_TG6,
     OR_TYPEID_OLYMPUS_EM5III,
-    OR_TYPEID_OLYMPUS_SP565,
+    OR_TYPEID_OLYMPUS_SP565UZ,
     OR_TYPEID_OLYMPUS_EPL10,
     OR_TYPEID_OLYMPUS_EM1III,
-    OR_TYPEID_OLYMPUS_EM10IV,
+    OR_TYPEID_OLYMPUS_EM10IV = 51,
+    OR_TYPEID_OLYMPUS_EM10IIIS = 52,
+    OR_TYPEID_OLYMPUS_OM1 = 53,
 
     _OR_TYPEID_OLYMPUS_LAST
 };
 
-enum {
+/** @brief Samsung type IDs */
+enum _OR_TYPEID_VENDOR_SAMSUNG {
     OR_TYPEID_SAMSUNG_UNKNOWN = 0,
     OR_TYPEID_SAMSUNG_GX10,
     OR_TYPEID_SAMSUNG_PRO815,
     _OR_TYPEID_SAMSUNG_LAST
 };
 
-enum {
+/** @brief Ricoh type IDs
+ *
+ * Following the merger with Pentax newer cameras may be Pentax.
+ */
+enum _OR_TYPEID_VENDOR_RICOH {
     OR_TYPEID_RICOH_UNKNOWN = 0,
     OR_TYPEID_RICOH_GR2 = 1,
     OR_TYPEID_RICOH_GXR = 2,
@@ -503,17 +558,19 @@ enum {
     OR_TYPEID_PENTAX_645Z_DNG = 7,
     OR_TYPEID_RICOH_GRII = 8,
     OR_TYPEID_RICOH_GRIII = 9,
+    OR_TYPEID_RICOH_GRIIIX = 10,
     _OR_TYPEID_RICOH_LAST
 };
 
-enum {
+/** @brief Sony type IDs */
+enum _OR_TYPEID_VENDOR_SONY {
     OR_TYPEID_SONY_UNKNOWN = 0,
     OR_TYPEID_SONY_A100 = 1,
     OR_TYPEID_SONY_A200 = 2,
     OR_TYPEID_SONY_A700 = 3,
     OR_TYPEID_SONY_A550 = 4,
     OR_TYPEID_SONY_A380 = 5,
-    OR_TYPEID_SONY_A390 = 6,
+    OR_TYPEID_SONY_A390 = OR_TYPEID_SONY_A380,
     OR_TYPEID_SONY_SLTA55 = 7,
     OR_TYPEID_SONY_SLTA77 = 8,
     OR_TYPEID_SONY_NEX3 = 9,
@@ -528,7 +585,6 @@ enum {
     OR_TYPEID_SONY_NEXF3 = 18,
     OR_TYPEID_SONY_SLTA65 = 19,
     OR_TYPEID_SONY_A330 = 21,
-    OR_TYPEID_SONY_A350 = 21,
     OR_TYPEID_SONY_A450 = 22,
     OR_TYPEID_SONY_A580 = 23,
     OR_TYPEID_SONY_A850 = 24,
@@ -578,7 +634,6 @@ enum {
     OR_TYPEID_SONY_A290 = 67,
     OR_TYPEID_SONY_RX100M5A = 68,
     OR_TYPEID_SONY_HX99 = 69,
-    OR_TYPEID_SONY_HX95 = OR_TYPEID_SONY_HX99,
     OR_TYPEID_SONY_ILCE6400 = 70,
     OR_TYPEID_SONY_RX0M2 = 71,
     OR_TYPEID_SONY_ILCE7RM4 = 72,
@@ -589,10 +644,23 @@ enum {
     OR_TYPEID_SONY_ZV1 = 77,
     // SR2 file
     OR_TYPEID_SONY_R1 = 78,
+    // ARW
+    OR_TYPEID_SONY_ILCE7SM3 = 79,
+    OR_TYPEID_SONY_ILCE7C = 80,
+    OR_TYPEID_SONY_ZVE10 = 81,
+    OR_TYPEID_SONY_ILCE1 = 82,
+    OR_TYPEID_SONY_ILCE7M4 = 83,
+    OR_TYPEID_SONY_ILCEQX1 = 84,
+    OR_TYPEID_SONY_A350 = 85,
+    OR_TYPEID_SONY_A300 = 86,
+    OR_TYPEID_SONY_ILCE7RM3A = 87,
+    OR_TYPEID_SONY_ILCE7RM4A = 88,
+    OR_TYPEID_SONY_HX95 = 89,
     _OR_TYPEID_SONY_LAST
 };
 
-enum {
+/** @brief Panasonic type IDs */
+enum _OR_TYPEID_VENDOR_PANASONIC {
     OR_TYPEID_PANASONIC_UNKNOWN = 0,
     OR_TYPEID_PANASONIC_GF1 = 1,
     OR_TYPEID_PANASONIC_GF2 = 2,
@@ -679,10 +747,16 @@ enum {
     OR_TYPEID_PANASONIC_DC_G91 = OR_TYPEID_PANASONIC_DC_G99,
     OR_TYPEID_PANASONIC_DC_S1H = 70,
     OR_TYPEID_PANASONIC_DC_G100 = 71,
+    OR_TYPEID_PANASONIC_DC_G110 = OR_TYPEID_PANASONIC_DC_G100,
+    OR_TYPEID_PANASONIC_DC_S5 = 72,
+    OR_TYPEID_PANASONIC_GH5M2 = 73,
+    OR_TYPEID_PANASONIC_GH6 = 74,
+    OR_TYPEID_PANASONIC_G7 = 75,
     _OR_TYPEID_PANASONIC_LAST
 };
 
-enum {
+/** @brief Fujifilm type IDs */
+enum _OR_TYPEID_VENDOR_FUJIFILM {
     OR_TYPEID_FUJIFILM_UNKNOWN = 0,
     OR_TYPEID_FUJIFILM_F700 = 1,
     OR_TYPEID_FUJIFILM_E900 = 2,
@@ -739,56 +813,89 @@ enum {
     OR_TYPEID_FUJIFILM_X100V = 52,
     OR_TYPEID_FUJIFILM_XT4 = 53,
     OR_TYPEID_FUJIFILM_F550EXR = 54,
+    OR_TYPEID_FUJIFILM_S100FS = 55,
+    OR_TYPEID_FUJIFILM_XS10 = 56,
+    OR_TYPEID_FUJIFILM_XT30_II = 57,
+    OR_TYPEID_FUJIFILM_GFX50S_II = 58,
+    OR_TYPEID_FUJIFILM_GFX100S = 59,
+    OR_TYPEID_FUJIFILM_XE4 = 60,
     _OR_TYPEID_FUJIFILM_LAST
 };
 
-enum {
+enum _OR_TYPEID_VENDOR_BLACKMAGIC {
     OR_TYPEID_BLACKMAGIC_UNKNOWN = 0,
     OR_TYPEID_BLACKMAGIC_POCKET_CINEMA = 1,
     _OR_TYPEID_BLACKMAGIC_LAST
 };
 
-enum {
+enum _OR_TYPEID_VENDOR_XIAOYI {
     OR_TYPEID_XIAOYI_UNKNOWN = 0,
     OR_TYPEID_XIAOYI_M1 = 1,
+    OR_TYPEID_XIAOYI_YDXJ_2 = 2,
+    OR_TYPEID_XIAOYI_YIAC_3 = 3,
     _OR_TYPEID_XIAOYI_LAST
 };
 
-enum {
+enum _OR_TYPEID_VENDOR_APPLE {
     OR_TYPEID_APPLE_UNKNOWN = 0,
     OR_TYPEID_APPLE_IPHONE_6SPLUS = 1,
     OR_TYPEID_APPLE_IPHONE_7PLUS = 2,
     OR_TYPEID_APPLE_IPHONE_SE = 3,
     OR_TYPEID_APPLE_IPHONE_8 = 4,
     OR_TYPEID_APPLE_IPHONE_XS = 5,
+    OR_TYPEID_APPLE_IPHONE_12_PRO = 6,
+    OR_TYPEID_APPLE_IPHONE_13_PRO = 7,
     _OR_TYPEID_APPLE_LAST
 };
 
-enum {
+enum _OR_TYPEID_VENDOR_SIGMA {
     OR_TYPEID_SIGMA_UNKNOWN = 0,
     OR_TYPEID_SIGMA_FP = 1,
+    OR_TYPEID_SIGMA_FP_L = 2,
     _OR_TYPEID_SIGMA_LAST
 };
 
-enum {
+enum _OR_TYPEID_VENDOR_GOPRO {
     OR_TYPEID_GOPRO_UNKNOWN = 0,
     OR_TYPEID_GOPRO_HERO5_BLACK = 1,
     OR_TYPEID_GOPRO_HERO6_BLACK = 2,
     OR_TYPEID_GOPRO_HERO7_BLACK = 3,
     OR_TYPEID_GOPRO_HERO8_BLACK = 4,
+    OR_TYPEID_GOPRO_HERO9_BLACK = 5,
+    OR_TYPEID_GOPRO_HERO10_BLACK = 6,
 
     _OR_TYPEID_GOPRO_LAST
 };
 
-enum {
+enum _OR_TYPEID_VENDOR_HASSELBLAD {
     OR_TYPEID_HASSELBLAD_UNKNOWN = 0,
     OR_TYPEID_HASSELBLAD_LUNAR = 1,
+    OR_TYPEID_HASSELBLAD_L1D_20C = 2,
 
     _OR_TYPEID_HASSELBLAD_LAST
 };
 
+enum _OR_TYPEID_VENDOR_ZEISS {
+    OR_TYPEID_ZEISS_UNKNOWN = 0,
+    OR_TYPEID_ZEISS_ZX1 = 1,
+
+    _OR_TYPEID_ZEISS_LAST
+};
+
+enum _OR_TYPEID_VENDOR_DJI {
+    OR_TYPEID_DJI_UNKNOWN = 0,
+    OR_TYPEID_DJI_FC350 = 1,
+    OR_TYPEID_DJI_FC7303 = 2,
+    OR_TYPEID_DJI_OSMO_ACTION = 3,
+    OR_TYPEID_DJI_FC220 = 4,
+    OR_TYPEID_DJI_FC6310 = 5,
+
+    _OR_TYPEID_DJI_LAST
+};
+
 #ifdef __cplusplus
 }
 #endif
 
+/** @} */
 #endif
